/* globals ExtensionAPI XPCOMUtils */
ChromeUtils.defineModuleGetter(this, "Services",
  "resource://gre/modules/Services.jsm");
ChromeUtils.defineModuleGetter(this, "AddonManager",
  "resource://gre/modules/AddonManager.jsm");
ChromeUtils.defineModuleGetter(this, "ExtensionCommon",
  "resource://gre/modules/ExtensionCommon.jsm");

const ABORT_PREF = "extensions.etp_rollout.completed";

class PrefHelperEventEmitter extends ExtensionCommon.EventEmitter {
  emitAbort() {
    this.emit("abort");
  }
}

this.prefHelper = class extends ExtensionAPI {
  getAPI(context) {
    const prefHelperEventEmitter = new PrefHelperEventEmitter();
    return {
      prefHelper: {
        observeAbortPref() {
          AddonManager.addAddonListener(this);
          Services.prefs.addObserver(ABORT_PREF, this.abort);
        },
        async getAbortedPref() {
          return Services.prefs.getBoolPref(ABORT_PREF, false);
        },
        abort() {
          if (Services.prefs.getBoolPref(ABORT_PREF, false)) {
            prefHelperEventEmitter.emitAbort();
          }
        },
        onUninstalling(addon) {
          this.handleDisableOrUninstall(addon);
        },
        onDisabled(addon) {
          this.handleDisableOrUninstall(addon);
        },
        handleDisableOrUninstall(addon) {
          if (addon.id !== context.extension.id) {
            return;
          }
          Services.prefs.removeObserver(ABORT_PREF, this.abort);
          AddonManager.removeAddonListener(this);
        },

        onAbort: new ExtensionCommon.EventManager(
          context,
          "prefHelper.onAbort",
          fire => {
            const listener = (value) => {
              fire.async();
            };
            prefHelperEventEmitter.on(
              "abort",
              listener,
            );
            return () => {
              prefHelperEventEmitter.off(
                "abort",
                listener,
              );
            };
          },
        ).api(),
      },
    };
  }
};
